commit:     7fdb50bd3be0467d2bfefac8fde9554ed7956cce
Author:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
AuthorDate: Wed Jan 10 21:01:55 2018 +0000
Commit:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
CommitDate: Wed Jan 10 21:01:55 2018 +0000
URL:        https://gitweb.gentoo.org/proj/grss.git/commit/?id=7fdb50bd

grs/Netboot.py: switch from xz to gzip compression

 grs/Netboot.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/grs/Netboot.py b/grs/Netboot.py
index 985bcfd..307b3b3 100644
--- a/grs/Netboot.py
+++ b/grs/Netboot.py
@@ -65,9 +65,9 @@ class Netboot(HashIt):
         shutil.rmtree(initramfs_root, ignore_errors=True)
         os.makedirs(initramfs_root, mode=0o755, exist_ok=False)
 
         # We will only use xz compression
         initramfs_src = os.path.join(self.portage_configroot, 'boot/initramfs')
-        cmd = 'xz -dc %s | cpio -idv' % (initramfs_src)
+        cmd = 'cat %s | gunzip | cpio -idv' % (initramfs_src)
 
         cwd = os.getcwd()
         os.chdir(initramfs_root)
@@ -95,7 +95,7 @@ class Netboot(HashIt):
         shutil.rmtree(squashfs_dir, ignore_errors=True)
         os.makedirs(squashfs_dir, mode=0o755, exist_ok=False)
         squashfs_path = os.path.join(squashfs_dir, 'image.squashfs')
-        cmd = 'mksquashfs %s %s -xattrs -comp xz' % (self.portage_configroot, 
squashfs_path)
+        cmd = 'mksquashfs %s %s -xattrs -comp gzip' % 
(self.portage_configroot, squashfs_path)
         Execute(cmd, timeout=None, logfile=self.logfile)
 
         # 4. Copy in the init script
@@ -106,7 +106,7 @@ class Netboot(HashIt):
 
         # 5. Repack
         initramfs_dst = os.path.join(self.tmpdir, self.medium_name)
-        cmd = 'find . -print | cpio -H newc -o | xz -9e --check=none -z -f > 
%s' % initramfs_dst
+        cmd = 'find . -print | cpio -H newc -o | gzip -9 -f > %s' % 
initramfs_dst
 
         cwd = os.getcwd()
@@ -65,9 +65,9 @@ class Netboot(HashIt):
         os.makedirs(initramfs_root, mode=0o755, exist_ok=False)
 
-        # We will only use xz compression
+        # We will use gzip compression
         initramfs_src = os.path.join(self.portage_configroot, 'boot/initramfs')
         os.chdir(initramfs_root)

Reply via email to